@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-gst.c,v 1.38 2003/06/22 19:49:26 dolphy Exp $
+ * $Id: bacon-video-widget-gst.c,v 1.41 2003/06/27 20:39:28 dolphy Exp $
  *
  */
 
@@ -621,6 +621,18 @@ bacon_video_widget_get_tv_out (BaconVideoWidget * bvw)
   return TV_OUT_NONE;
 }
 
+BaconVideoWidgetAudioOutType
+bacon_video_widget_get_audio_out_type (BaconVideoWidget *bvw)
+{
+  return BVW_AUDIO_SOUND_STEREO;
+}
+
+void
+bacon_video_widget_set_audio_out_type (BaconVideoWidget *bvw,
+                                       BaconVideoWidgetAudioOutType type)
+{
+  
+}
 
 /* =========================================== */
 /*                                             */
@@ -640,6 +652,7 @@ bacon_video_widget_open (BaconVideoWidget * bvw, const gchar * mrl,
   g_return_val_if_fail (bvw->priv->play != NULL, FALSE);
   g_return_val_if_fail (bvw->priv->mrl == NULL, FALSE);
 
+  g_message ("open %s", mrl);
   bvw->priv->mrl = g_strdup (mrl);
 
   /* Resetting last_error_message to NULL */
@@ -709,6 +722,11 @@ bacon_video_widget_play (BaconVideoWidget * bvw,
       seek_time = (gint64) (length_nanos * pos / 65535);
       gst_play_seek_to_time (bvw->priv->play, seek_time);
     }
+  else if (start_time)
+    {
+      seek_time = (gint64) (start_time * GST_MSECOND);
+      gst_play_seek_to_time (bvw->priv->play, seek_time);
+    }
   else
     {
       gst_play_set_state (bvw->priv->play, GST_STATE_PLAYING);
@@ -1020,12 +1038,12 @@ bacon_video_widget_set_visuals_quality (BaconVideoWidget * bvw,
   switch (quality)
     {
     case VISUAL_SMALL:
-      fps = 25;
-      w = 160;
-      h = 120;
+      fps = 15;
+      w = 320;
+      h = 240;
       break;
     case VISUAL_NORMAL:
-      fps = 15;
+      fps = 25;
       w = 320;
       h = 240;
       break;
@@ -1035,9 +1053,9 @@ bacon_video_widget_set_visuals_quality (BaconVideoWidget * bvw,
       h = 480;
       break;
     case VISUAL_EXTRA_LARGE:
-      fps = 25;
-      w = 1024;
-      h = 768;
+      fps = 30;
+      w = 800;
+      h = 600;
       break;
     default:
       /* shut up warnings */
@@ -1172,7 +1190,18 @@ bacon_video_widget_can_play (BaconVideoWidget * bvw, MediaType type)
   g_return_val_if_fail (bvw != NULL, FALSE);
   g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), FALSE);
   g_return_val_if_fail (GST_IS_PLAY (bvw->priv->play), FALSE);
-  return FALSE;
+  
+  switch (type)
+    {
+      case MEDIA_DVD:
+        return FALSE;
+      case MEDIA_VCD:
+        return FALSE;
+      case MEDIA_CDDA:
+        return FALSE;
+      default:
+        return FALSE;
+    }
 }
 
 G_CONST_RETURN gchar **
