@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.44 2003/06/22 19:11:28 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.53 2003/07/05 11:56:20 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -42,6 +42,7 @@
 #include "baconvideowidget-marshal.h"
 #include "scrsaver.h"
 #include "video-utils.h"
+#include "bacon-resize.h"
 
 #include <libintl.h>
 #define _(String) gettext (String)
@@ -54,7 +55,6 @@
 #define DEFAULT_HEIGHT 315
 #define DEFAULT_WIDTH 420
 #define CONFIG_FILE ".gnome2"G_DIR_SEPARATOR_S"totem_config"
-#define DEFAULT_TITLE _("Totem Video Window")
 
 /* Signals */
 enum {
@@ -119,6 +119,9 @@ struct BaconVideoWidgetPrivate {
 	xine_vo_driver_t *vo_driver;
 	xine_ao_driver_t *ao_driver;
 	xine_event_queue_t *ev_queue;
+#if 0
+	xine_osd_t *osd;
+#endif
 	double display_ratio;
 	gboolean started;
 
@@ -146,7 +149,7 @@ struct BaconVideoWidgetPrivate {
 	guint tick_id;
 	gboolean auto_resize;
 	GdkPixbuf *icon;
-	gint volume;
+	int volume;
 	TvOutType tvout;
 	guint32 video_fcc, audio_fcc;
 
@@ -157,6 +160,7 @@ struct BaconVideoWidgetPrivate {
 	/* fullscreen stuff */
 	gboolean fullscreen_mode;
 	gboolean cursor_shown;
+	int screenid;
 };
 
 static const char *mms_bandwidth_strs[]={"14.4 Kbps (Modem)",
@@ -435,13 +439,13 @@ bacon_video_widget_finalize (GObject *object)
 }
 
 static void
-dest_size_cb (void *bvw_gen,
+dest_size_cb (void *data,
 	      int video_width, int video_height,
 	      double video_pixel_aspect,
 	      int *dest_width, int *dest_height,
 	      double *dest_pixel_aspect)
 {
-	BaconVideoWidget *bvw = (BaconVideoWidget *) bvw_gen;
+	BaconVideoWidget *bvw = (BaconVideoWidget *)data;
 
 	/* correct size with video_pixel_aspect */
 	if (video_pixel_aspect >= bvw->priv->display_ratio)
@@ -493,8 +497,9 @@ frame_output_cb (void *bvw_gen,
 		bvw->priv->video_width = video_width;
 		bvw->priv->video_height = video_height;
 
-		if (bvw->priv->auto_resize == TRUE
-				&& bvw->priv->logo_mode == FALSE)
+		if (bvw->priv->auto_resize != FALSE
+				&& bvw->priv->logo_mode == FALSE
+				&& bvw->priv->fullscreen_mode == FALSE)
 		{
 			signal_data *data;
 
@@ -503,6 +508,9 @@ frame_output_cb (void *bvw_gen,
 			g_async_queue_push (bvw->priv->queue, data);
 			g_idle_add ((GSourceFunc)
 					bacon_video_widget_idle_signal, bvw);
+		} else if (bvw->priv->auto_resize != FALSE
+				&& bvw->priv->fullscreen_mode == TRUE) {
+			bacon_resize (video_height, video_width);
 		}
 	}
 
@@ -527,9 +535,11 @@ load_video_out_driver (BaconVideoWidget *bvw, gboolean null_out)
 	vis.screen = bvw->priv->screen;
 	vis.d = GDK_WINDOW_XID (bvw->priv->video_window);
 	res_h = (DisplayWidth (bvw->priv->display, bvw->priv->screen) * 1000 /
-	     DisplayWidthMM (bvw->priv->display, bvw->priv->screen));
+			DisplayWidthMM (bvw->priv->display,
+				bvw->priv->screen));
 	res_v = (DisplayHeight (bvw->priv->display, bvw->priv->screen) * 1000 /
-	     DisplayHeightMM (bvw->priv->display, bvw->priv->screen));
+			DisplayHeightMM (bvw->priv->display,
+				bvw->priv->screen));
 	bvw->priv->display_ratio = res_v / res_h;
 
 	if (fabs (bvw->priv->display_ratio - 1.0) < 0.01) {
@@ -744,6 +754,20 @@ setup_config_video (BaconVideoWidget *bvw)
 		xine_config_update_entry (bvw->priv->xine, &entry);
 	}
 }
+#if 0
+static void
+setup_osd (BaconVideoWidget *bvw)
+{
+	int fonth = 20;
+
+	bvw->priv->osd = xine_osd_new(bvw->priv->stream,
+			0, 0, 900, (fonth * 6) + (5 * 3));
+	xine_osd_set_font(bvw->priv->osd, "/home/hadess/.fonts/helvetica.ttf", fonth * 10);
+	xine_osd_set_text_palette(bvw->priv->osd,
+			XINE_TEXTPALETTE_WHITE_NONE_TRANSPARENT,
+			XINE_OSD_TEXT1);
+}
+#endif
 
 static void
 setup_config_stream (BaconVideoWidget *bvw)
@@ -753,6 +777,7 @@ setup_config_stream (BaconVideoWidget *bvw)
 	if (bvw->priv->gc == NULL)
 		return;
 
+	/* Setup brightness and contrast */
 	for (i = 0; i < 2; i++)
 	{
 		value = gconf_client_get_int (bvw->priv->gc, video_props_str[i], NULL);
@@ -924,16 +949,36 @@ generate_mouse_event (BaconVideoWidget *bvw, GdkEvent *event,
 }
 
 static gboolean
-configure_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer user_data)
+configure_cb (GtkWidget *widget, GdkEventConfigure *event,
+		BaconVideoWidget *bvw)
 {
-	BaconVideoWidget *bvw = (BaconVideoWidget *) user_data;
-
 	bvw->priv->xpos = event->x + GTK_WIDGET (bvw)->allocation.x;
 	bvw->priv->ypos = event->y + GTK_WIDGET (bvw)->allocation.y;
 
 	return FALSE;
 }
 
+static void
+size_changed_cb (GdkScreen *screen, BaconVideoWidget *bvw)
+{
+	double res_h, res_v;
+
+	XLockDisplay (bvw->priv->display);
+	res_h = (DisplayWidth (bvw->priv->display, bvw->priv->screen) * 1000 /
+			DisplayWidthMM (bvw->priv->display,
+				bvw->priv->screen));
+	res_v = (DisplayHeight (bvw->priv->display, bvw->priv->screen) * 1000 /
+			DisplayHeightMM (bvw->priv->display,
+				bvw->priv->screen));
+	XUnlockDisplay (bvw->priv->display);
+
+	bvw->priv->display_ratio = res_v / res_h;
+
+	if (fabs (bvw->priv->display_ratio - 1.0) < 0.01) {
+		bvw->priv->display_ratio = 1.0;
+	}
+}
+
 static void
 bacon_video_widget_realize (GtkWidget *widget)
 {
@@ -980,6 +1025,10 @@ bacon_video_widget_realize (GtkWidget *widget)
 			"configure-event",
 			G_CALLBACK (configure_cb), bvw);
 
+	/* get screen size changes */
+	g_signal_connect (G_OBJECT (gdk_screen_get_default ()),
+			"size-changed", G_CALLBACK (size_changed_cb), bvw);
+
 	/* Now onto the video out driver */
 	bvw->priv->display = XOpenDisplay (gdk_display_get_name
 			(gdk_display_get_default ()));
@@ -995,9 +1044,13 @@ bacon_video_widget_realize (GtkWidget *widget)
 				bvw->priv->vis_name, 0,
 				&bvw->priv->ao_driver, &bvw->priv->vo_driver);
 
+	bacon_resize_init ();
 	bvw->priv->stream = xine_stream_new (bvw->priv->xine,
 			bvw->priv->ao_driver, bvw->priv->vo_driver);
 	setup_config_stream (bvw);
+#if 0
+	setup_osd (bvw);
+#endif
 	bvw->priv->ev_queue = xine_event_new_queue (bvw->priv->stream);
 
 	/* Setup xine events */
@@ -1077,7 +1130,7 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 	case XINE_MSG_GENERAL_WARNING:
 		break;
 	case XINE_MSG_UNKNOWN_HOST:
-		message = g_strdup_printf (_("The server you are trying to connect to (%s) is not known."), (char *) data + data->parameters);
+		message = g_strdup_printf (_("The server you are trying to connect to is not known."));
 		break;
 	case XINE_MSG_UNKNOWN_DEVICE:
 		message = g_strdup_printf (_("The device name you specified (%s) seems to be invalid."), (char *) data + data->parameters);
@@ -1159,7 +1212,8 @@ xine_event (void *user_data, const xine_event_t *event)
 		break;
 	case XINE_EVENT_MRL_REFERENCE:
 		ref = event->data;
-		D("ref mrl detected: %s", ref->mrl);
+		bacon_video_widget_close (bvw);
+		bacon_video_widget_open (bvw, ref->mrl, NULL);
 		break;
 	case XINE_EVENT_UI_MESSAGE:
 		xine_event_message (bvw, (xine_ui_message_data_t *)event->data);
@@ -1212,6 +1266,10 @@ bacon_video_widget_unrealize (GtkWidget *widget)
 
 	bvw = BACON_VIDEO_WIDGET (widget);
 
+	/* stop the playback */
+	xine_stop (bvw->priv->stream);
+	xine_close (bvw->priv->stream);
+
 	/* Kill the TV out */
 	xine_tvmode_exit (bvw->priv->xine);
 
@@ -1220,8 +1278,11 @@ bacon_video_widget_unrealize (GtkWidget *widget)
 		gtk_widget_unmap (widget);
 	GTK_WIDGET_UNSET_FLAGS (widget, GTK_MAPPED);
 
-	/* stop the playback */
-	xine_close (bvw->priv->stream);
+	/* Kill the OSD */
+#if 0
+	xine_osd_hide (bvw->priv->osd, 0);
+	xine_osd_free (bvw->priv->osd);
+#endif
 
 	/* Get rid of the rest of the stream */
 	xine_event_dispose_queue (bvw->priv->ev_queue);
@@ -1233,6 +1294,12 @@ bacon_video_widget_unrealize (GtkWidget *widget)
 	entry.num_value = bvw->priv->volume;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 
+	/* save config */
+	configfile = g_build_path (G_DIR_SEPARATOR_S,
+			g_get_home_dir (), CONFIG_FILE, NULL);
+	xine_config_save (bvw->priv->xine, configfile);
+	g_free (configfile);
+
 	/* Kill the drivers */
 	if (bvw->priv->vo_driver != NULL)
 		xine_close_video_driver (bvw->priv->xine,
@@ -1241,12 +1308,6 @@ bacon_video_widget_unrealize (GtkWidget *widget)
 		xine_close_audio_driver (bvw->priv->xine,
 				bvw->priv->ao_driver);
 
-	/* save config */
-	configfile = g_build_path (G_DIR_SEPARATOR_S,
-			g_get_home_dir (), CONFIG_FILE, NULL);
-	xine_config_save (bvw->priv->xine, configfile);
-	g_free (configfile);
-
 	/* stop event thread */
 	xine_exit (bvw->priv->xine);
 	bvw->priv->xine = NULL;
@@ -1623,6 +1684,26 @@ bacon_video_widget_play (BaconVideoWidget *bvw, guint pos,
 		xine_error (bvw, gerror);
 		return FALSE;
 	}
+#if 0
+	if (pos == 0 && start_time == 0 && bvw->priv->using_vfx == TRUE)
+	{
+		char *name;
+
+		name = g_strdup_printf ("%s - %s",
+				xine_get_meta_info (bvw->priv->stream,
+					XINE_META_INFO_ARTIST),
+				xine_get_meta_info (bvw->priv->stream,
+					XINE_META_INFO_TITLE));
+
+		xine_osd_clear (bvw->priv->osd);
+		xine_osd_draw_text (bvw->priv->osd, 0, 0, name, XINE_OSD_TEXT1);
+		xine_osd_set_position(bvw->priv->osd, 20, 10 + 30);
+		xine_osd_show(bvw->priv->osd, 0);
+		/* Hide in... vpts is in 1/90000 sec */
+		//FIXME
+		//xine_osd_hide (bvw->priv->osd, 90000 * 8);
+	}
+#endif
 	return TRUE;
 }
 
@@ -1898,6 +1979,18 @@ bacon_video_widget_get_volume (BaconVideoWidget *bvw)
 void
 bacon_video_widget_set_fullscreen (BaconVideoWidget *bvw, gboolean fullscreen)
 {
+	if (bvw->priv->auto_resize == FALSE)
+		return;
+
+	if (fullscreen == FALSE)
+	{
+		bacon_restore (bvw->priv->screenid);
+	} else {
+		bvw->priv->screenid = bacon_resize_get_current ();
+		bacon_resize (bvw->priv->video_height,
+				bvw->priv->video_width);
+	} 
+	bvw->priv->fullscreen_mode = fullscreen;
 }
 
 void
@@ -2475,6 +2568,69 @@ bacon_video_widget_set_video_property (BaconVideoWidget *bvw,
 	gconf_client_set_int (bvw->priv->gc, video_props_str[type], value, NULL);
 }
 
+BaconVideoWidgetAudioOutType
+bacon_video_widget_get_audio_out_type (BaconVideoWidget *bvw)
+{
+	g_return_if_fail (bvw != NULL);
+	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
+	g_return_if_fail (bvw->priv->xine != NULL);
+
+	return gconf_client_get_int (bvw->priv->gc,
+			GCONF_PREFIX"/audio_output_type", NULL);
+}
+
+void
+bacon_video_widget_set_audio_out_type (BaconVideoWidget *bvw,
+		BaconVideoWidgetAudioOutType type)
+{
+	xine_cfg_entry_t entry;
+	int four_channel, five_channel, five_one_channel;
+
+	g_return_if_fail (bvw != NULL);
+	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
+	g_return_if_fail (bvw->priv->xine != NULL);
+
+	four_channel = five_channel = five_one_channel = 0;
+
+	gconf_client_set_int (bvw->priv->gc,
+			GCONF_PREFIX"/audio_output_type",
+			type, NULL);
+	switch (type) {
+	case BVW_AUDIO_SOUND_STEREO:
+		/* Nothing to do */
+		break;
+	case BVW_AUDIO_SOUND_4CHANNEL:
+		four_channel = 1;
+		break;
+	case BVW_AUDIO_SOUND_5CHANNEL:
+		five_channel = 1;
+		break;
+	case BVW_AUDIO_SOUND_51CHANNEL:
+		five_one_channel = 1;
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+
+	if (xine_config_lookup_entry (bvw->priv->xine, "audio.four_channel", &entry))
+	{
+		entry.num_value = four_channel;
+		xine_config_update_entry (bvw->priv->xine, &entry);
+	}
+
+	if (xine_config_lookup_entry (bvw->priv->xine, "audio.five_channel", &entry))
+	{
+		entry.num_value = five_channel;
+		xine_config_update_entry (bvw->priv->xine, &entry);
+	}
+
+	if (xine_config_lookup_entry (bvw->priv->xine, "audio.five_lfe_channel", &entry))
+	{
+		entry.num_value = five_one_channel;
+		xine_config_update_entry (bvw->priv->xine, &entry);
+	}
+}
+
 static void
 bacon_video_widget_get_metadata_string (BaconVideoWidget *bvw, BaconVideoWidgetMetadataType type,
 		GValue *value)
@@ -2485,7 +2641,7 @@ bacon_video_widget_get_metadata_string (BaconVideoWidget *bvw, BaconVideoWidgetM
 
 	if (bvw->priv->stream == NULL)
 	{
-		g_value_set_string (value, "");
+		g_value_set_string (value, string);
 		return;
 	}
 
@@ -2515,6 +2671,22 @@ bacon_video_widget_get_metadata_string (BaconVideoWidget *bvw, BaconVideoWidgetM
 		g_assert_not_reached ();
 	}
 
+	if (string != NULL && string[0] == '\0')
+		string = NULL;
+
+	if (string != NULL)
+	{
+		if (g_utf8_validate (string, -1, NULL) == FALSE)
+		{
+			char *utf8;
+
+			utf8 = g_locale_to_utf8 (string, -1, NULL, NULL, NULL);
+			g_value_set_string (value, utf8);
+			g_free (utf8);
+			return;
+		}
+	}
+
 	g_value_set_string (value, string);
 
 	return;
