@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.27 2003/06/21 01:49:31 hadess Exp $
+ * $Id: bacon-video-widget.h,v 1.28 2003/06/24 16:06:49 hadess Exp $
  *
  * the xine engine in a widget - header
  */
@@ -69,6 +69,13 @@ typedef enum {
 	BVW_VIDEO_CONTRAST,
 } BaconVideoWidgetVideoProperty;
 
+typedef enum {
+	BVW_AUDIO_SOUND_STEREO,
+	BVW_AUDIO_SOUND_4CHANNEL,
+	BVW_AUDIO_SOUND_5CHANNEL,
+	BVW_AUDIO_SOUND_51CHANNEL,
+} BaconVideoWidgetAudioOutType;
+
 #define BACON_VIDEO_WIDGET(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), bacon_video_widget_get_type (), BaconVideoWidget))
 #define BACON_VIDEO_WIDGET_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), bacon_video_widget_get_type (), BaconVideoWidgetClass))
 #define BACON_IS_VIDEO_WIDGET(obj)           (G_TYPE_CHECK_INSTANCE_TYPE (obj, bacon_video_widget_get_type ()))
@@ -174,6 +181,12 @@ void bacon_video_widget_set_video_property	 (BaconVideoWidget *bvw,
 						  type,
 						  int value);
 
+BaconVideoWidgetAudioOutType bacon_video_widget_get_audio_out_type
+						 (BaconVideoWidget *bvw);
+void bacon_video_widget_set_audio_out_type	 (BaconVideoWidget *bvw,
+						  BaconVideoWidgetAudioOutType
+						  type);
+
 int bacon_video_widget_get_position              (BaconVideoWidget *bvw);
 int bacon_video_widget_get_current_time          (BaconVideoWidget *bvw);
 int bacon_video_widget_get_stream_length         (BaconVideoWidget *bvw);
