@@ -99,7 +99,43 @@ on_checkbutton1_toggled (GtkToggleButton *togglebutton, Totem *totem)
 		(BACON_VIDEO_WIDGET (totem->bvw), value);
 }
 
-static void              
+static void
+totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
+{
+	GtkWidget *item;
+
+	gconf_client_set_bool (totem->gc,
+			GCONF_PREFIX"/show_vfx", value, NULL);
+
+	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_label");
+	gtk_widget_set_sensitive (item, value);
+	item = glade_xml_get_widget (totem->xml,
+			"tpw_visuals_type_optionmenu");
+	gtk_widget_set_sensitive (item, value);
+	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_label");
+	gtk_widget_set_sensitive (item, value);
+	item = glade_xml_get_widget (totem->xml,
+			"tpw_visuals_size_optionmenu");
+	gtk_widget_set_sensitive (item, value);
+
+	if (warn == FALSE)
+	{
+		bacon_video_widget_set_show_visuals
+			(BACON_VIDEO_WIDGET (totem->bvw), value);
+		return;
+	}
+
+	if (bacon_video_widget_set_show_visuals
+			(BACON_VIDEO_WIDGET (totem->bvw), value) == FALSE)
+	{
+		totem_action_error (_("The change of this setting will only "
+					"take effect for the next movie, or "
+					"when Totem is restarted"),
+				totem);
+	}
+}
+
+static void
 on_checkbutton2_toggled (GtkToggleButton *togglebutton, Totem *totem)
 {
 	GtkWidget *item;
@@ -118,25 +154,7 @@ on_checkbutton2_toggled (GtkToggleButton *togglebutton, Totem *totem)
 		}
 	}
 
-	gconf_client_set_bool (totem->gc, GCONF_PREFIX"/show_vfx", value, NULL);
-
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_label");
-	gtk_widget_set_sensitive (item, value);
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_optionmenu");
-	gtk_widget_set_sensitive (item, value);
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_label");
-	gtk_widget_set_sensitive (item, value);
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_optionmenu");
-	gtk_widget_set_sensitive (item, value);
-
-	if (bacon_video_widget_set_show_visuals
-		(BACON_VIDEO_WIDGET (totem->bvw), value) == FALSE)
-	{
-		totem_action_error (_("The change of this setting will only "
-					"take effect for the next movie, or "
-					"when Totem is restarted"),
-				totem);
-	}
+	totem_prefs_set_show_visuals (totem, value, TRUE);
 }
 
 static void
@@ -341,6 +359,34 @@ bacon_cd_selection_create (void)
 	return widget;
 }
 
+static void
+brightness_changed (GtkRange *range, Totem *totem)
+{
+	gdouble i;
+
+	i = gtk_range_get_value (range);
+	bacon_video_widget_set_video_property (totem->bvw,
+			BVW_VIDEO_BRIGHTNESS, (int) i);
+}
+
+static void
+contrast_changed (GtkRange *range, Totem *totem)
+{
+	gdouble i;
+
+	i = gtk_range_get_value (range);
+	bacon_video_widget_set_video_property (totem->bvw,
+			BVW_VIDEO_CONTRAST, (int) i);
+}
+
+static void
+audio_out_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
+{
+	BaconVideoWidgetAudioOutType audio_out;
+	audio_out = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
+	bacon_video_widget_set_audio_out_type (totem->bvw, audio_out);
+}
+
 void
 totem_setup_preferences (Totem *totem)
 {
@@ -350,6 +396,7 @@ totem_setup_preferences (Totem *totem)
 	int connection_speed, i, found;
 	char *path, *visual;
 	GList *list, *l;
+	BaconVideoWidgetAudioOutType audio_out;
 
 	g_return_if_fail (totem->gc != NULL);
 
@@ -436,8 +483,7 @@ totem_setup_preferences (Totem *totem)
 
 	gtk_toggle_button_set_active
 		(GTK_TOGGLE_BUTTON (item), show_visuals);
-	bacon_video_widget_set_show_visuals
-		(BACON_VIDEO_WIDGET (totem->bvw), show_visuals);
+	totem_prefs_set_show_visuals (totem, show_visuals, FALSE);
 	g_signal_connect (G_OBJECT (item), "toggled",
 			G_CALLBACK (on_checkbutton2_toggled), totem);
 
@@ -481,6 +527,29 @@ totem_setup_preferences (Totem *totem)
 	g_signal_connect (G_OBJECT (item), "changed",
 			G_CALLBACK (visual_menu_changed), totem);
 
+	/* Brightness */
+	item = glade_xml_get_widget (totem->xml, "tpw_bright_scale");
+	i = bacon_video_widget_get_video_property (totem->bvw,
+			BVW_VIDEO_BRIGHTNESS);
+	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
+	g_signal_connect (G_OBJECT (item), "value-changed",
+			G_CALLBACK (brightness_changed), totem);
+
+	/* Contrast */
+	item = glade_xml_get_widget (totem->xml, "tpw_contrast_scale");
+	i = bacon_video_widget_get_video_property (totem->bvw,
+			BVW_VIDEO_CONTRAST);
+	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
+	g_signal_connect (G_OBJECT (item), "value-changed",
+			G_CALLBACK (contrast_changed), totem);
+
+	/* Sound output type */
+	item = glade_xml_get_widget (totem->xml, "tpw_sound_output_optionmenu");
+	audio_out = bacon_video_widget_get_audio_out_type (totem->bvw);
+	gtk_option_menu_set_history (GTK_OPTION_MENU (item), audio_out);
+	g_signal_connect (G_OBJECT (item), "changed",
+			G_CALLBACK (audio_out_menu_changed), totem);
+
 	/* This one is for the deinterlacing menu, not really our dialog
 	 * but we do it anyway */
 	item = glade_xml_get_widget (totem->xml, "tmw_deinterlace_menu_item");
