@@ -156,10 +156,10 @@ totem_statusbar_init (TotemStatusbar *statusbar)
 
   statusbar->has_resize_grip = TRUE;
   statusbar->time = 0;
-  statusbar->length = 0;
+  statusbar->length = -1;
 
   gtk_widget_style_get (GTK_WIDGET (statusbar), "shadow_type", &shadow_type, NULL);
-  
+ 
   statusbar->frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (statusbar->frame), shadow_type);
   gtk_box_pack_start (box, statusbar->frame, TRUE, TRUE, 0);
@@ -200,15 +200,20 @@ totem_statusbar_update_time (TotemStatusbar *statusbar)
   char *time, *length, *label;
 
   time = time_to_string (statusbar->time);
-  length = time_to_string (statusbar->length);
+
+  if (statusbar->length == 0) {
+    label = g_strdup_printf (_("%s (Streaming)"), time);
+  } else {
+  length = time_to_string (statusbar->length == -1 ? 0 : statusbar->length);
 
   //FIXME LTR/RTL
   label = g_strdup_printf ("%s / %s", time, length);
+  g_free (length);
+  }
 
   gtk_label_set_text (GTK_LABEL (statusbar->time_label), label);
 
   g_free (time);
-  g_free (length);
   g_free (label);
 }
 
