@@ -40,7 +40,6 @@
 #include "bacon-cd-selection.h"
 #include "totem-statusbar.h"
 #include "video-utils.h"
-#include "languages.h"
 
 #include "egg-recent-view.h"
 
@@ -112,21 +111,6 @@ long_action (void)
 		gtk_main_iteration ();
 }
 
-static char
-*language_name_get_from_code (const char *code)
-{
-	int i;
-
-	for (i = 0; languages[i].code != NULL; i++)
-	{
-		if (strstr (code, languages[i].code) != NULL)
-			return g_strdup (languages[i].language);
-	}
-
-	/* Ooops, not found */
-	return g_strdup (code);
-}
-
 static void
 totem_g_list_deep_free (GList *list)
 {
@@ -502,20 +486,12 @@ totem_action_fullscreen_toggle (Totem *totem)
 {
 	if (totem->controls_visibility == TOTEM_CONTROLS_FULLSCREEN)
 	{
-		gboolean auto_resize;
-
 		popup_hide (totem);
 		bacon_video_widget_set_fullscreen (totem->bvw, FALSE);
 		gtk_window_unfullscreen (GTK_WINDOW(totem->win));
 		bacon_video_widget_set_show_cursor (totem->bvw, TRUE);
 		scrsaver_enable (totem->scr);
 
-		/* Auto-resize */
-		auto_resize = gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/auto_resize", NULL);
-
-		bacon_video_widget_set_auto_resize (totem->bvw, auto_resize);
-
 		if (totem->controls_visibility != TOTEM_CONTROLS_VISIBLE)
 		{
 			GtkWidget *item;
@@ -536,7 +512,6 @@ totem_action_fullscreen_toggle (Totem *totem)
 	} else {
 		update_fullscreen_size (totem);
 		bacon_video_widget_set_fullscreen (totem->bvw, TRUE);
-		bacon_video_widget_set_auto_resize (totem->bvw, FALSE);
 		bacon_video_widget_set_show_cursor (totem->bvw, FALSE);
 		gtk_window_fullscreen (GTK_WINDOW(totem->win));
 		scrsaver_disable (totem->scr);
@@ -649,12 +624,11 @@ update_mrl_label (Totem *totem, const char *name)
 
 		/* Get the length of the stream */
 		time = bacon_video_widget_get_stream_length (totem->bvw);
-
-		//FIXME this doesn't work if the metadata arrives later
 		totem_statusbar_set_time_and_length (TOTEM_STATUSBAR
 				(totem->statusbar), 0, time / 1000);
 
-		widget = glade_xml_get_widget (totem->xml, "tstw_skip_spinbutton");
+		widget = glade_xml_get_widget (totem->xml,
+				"tstw_skip_spinbutton");
 		gtk_spin_button_set_range (GTK_SPIN_BUTTON (widget),
 				0, (gdouble) time / 1000);
 
@@ -1219,7 +1193,7 @@ on_error_event (BaconVideoWidget *bvw, char *message,
                 gboolean playback_stopped, Totem *totem)
 {
         if (playback_stopped)
-            play_pause_set_label (totem, STATE_STOPPED);
+		play_pause_set_label (totem, STATE_STOPPED);
 	totem_action_error (message, totem);
 }
 
@@ -1297,9 +1271,11 @@ update_seekable (Totem *totem, gboolean force_false)
 	gtk_widget_set_sensitive (totem->seek, caps);
 	gtk_widget_set_sensitive (totem->fs_seek, caps);
 
-	widget = glade_xml_get_widget (totem->xml, "tmw_skip_forward_menu_item");
+	widget = glade_xml_get_widget (totem->xml,
+			"tmw_skip_forward_menu_item");
 	gtk_widget_set_sensitive (widget, caps);
-	widget = glade_xml_get_widget (totem->xml, "tmw_skip_backwards_menu_item");
+	widget = glade_xml_get_widget (totem->xml,
+			"tmw_skip_backwards_menu_item");
 	gtk_widget_set_sensitive (widget, caps);
 	widget = glade_xml_get_widget (totem->xml, "trcm_skip_forward");
 	gtk_widget_set_sensitive (widget, caps);
@@ -1765,22 +1741,26 @@ show_controls (Totem *totem, gboolean visible, gboolean fullscreen_behaviour)
 	if (fullscreen_behaviour)
 		return;
 	
-	if (totem->controls_visibility == TOTEM_CONTROLS_HIDDEN) {
+	if (totem->controls_visibility == TOTEM_CONTROLS_HIDDEN)
+	{
 		gtk_window_resize (GTK_WINDOW(totem->win),
 			GTK_WIDGET(totem->bvw)->allocation.width,
 			GTK_WIDGET(totem->bvw)->allocation.height);
-	}
-	else if (totem->controls_visibility == TOTEM_CONTROLS_VISIBLE) {
+	} else if (totem->controls_visibility == TOTEM_CONTROLS_VISIBLE) {
 		/* We get GtkWindow requisition then we substract
 		bvw's requisition to get other widget's height and
 		use that to resize properly GtkWindow */
 		gtk_widget_size_request (totem->win, &requisition);
 		/* Getting controls requisition */
-		requisition.height = requisition.height - GTK_WIDGET(totem->bvw)->requisition.height;
-		requisition.width = requisition.width - GTK_WIDGET(totem->bvw)->requisition.width;
+		requisition.height = requisition.height
+			- GTK_WIDGET(totem->bvw)->requisition.height;
+		requisition.width = requisition.width
+			- GTK_WIDGET(totem->bvw)->requisition.width;
 		gtk_window_resize (GTK_WINDOW(totem->win),
-			GTK_WIDGET(totem->bvw)->allocation.width + requisition.width,
-			GTK_WIDGET(totem->bvw)->allocation.height + requisition.height);
+				GTK_WIDGET(totem->bvw)->allocation.width
+				+ requisition.width,
+				GTK_WIDGET(totem->bvw)->allocation.height
+				+ requisition.height);
 	}
 }
 
@@ -1880,9 +1860,23 @@ screenshot_make_filename_helper (char *filename, gboolean desktop_exists)
 {
 	if (desktop_exists == TRUE)
 	{
-		return g_build_filename (G_DIR_SEPARATOR_S,
-				g_get_home_dir (), ".gnome-desktop",
-				filename, NULL);
+		char *fullpath;
+
+		fullpath = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (),
+				"Desktop", NULL);
+		desktop_exists = g_file_test (fullpath, G_FILE_TEST_EXISTS);
+		g_free (fullpath);
+
+		if (desktop_exists == TRUE)
+		{
+			return g_build_filename (G_DIR_SEPARATOR_S,
+					g_get_home_dir (), "Desktop",
+					filename, NULL);
+		} else {
+			return g_build_filename (G_DIR_SEPARATOR_S,
+					g_get_home_dir (), ".gnome-desktop",
+					filename, NULL);
+		}
 	} else {
 		return g_build_filename (G_DIR_SEPARATOR_S,
 				g_get_home_dir (), filename, NULL);
@@ -2318,10 +2312,9 @@ update_fullscreen_size (Totem *totem)
 }
 
 static gboolean
-totem_is_fullscreen (Totem *totem) {
-	if (totem->controls_visibility == TOTEM_CONTROLS_FULLSCREEN)
-		return TRUE;
-	return FALSE;
+totem_is_fullscreen (Totem *totem)
+{
+	return (totem->controls_visibility == TOTEM_CONTROLS_FULLSCREEN);
 }
 
 static void
@@ -2375,6 +2368,7 @@ static gboolean
 on_video_motion_notify_event (GtkWidget *widget, GdkEventMotion *event,
 		Totem *totem)
 {
+	GtkWidget *item;
 	int width;
 
 	if (totem_is_fullscreen (totem) == FALSE) 
@@ -2391,6 +2385,9 @@ on_video_motion_notify_event (GtkWidget *widget, GdkEventMotion *event,
 		totem->popup_timeout = 0;
 	}
 
+	item = glade_xml_get_widget (totem->xml, "tmw_title_label");
+	gtk_widget_realize (item);
+
 	gtk_window_get_size (GTK_WINDOW (totem->control_popup),
 			&width, &totem->control_popup_height);
 	gtk_window_move (GTK_WINDOW (totem->exit_popup),
@@ -2833,11 +2830,9 @@ create_submenu (Totem *totem, GList *list, int current, gboolean is_lang)
 					current, -1, is_lang, group);
 		}
 
-		lang = language_name_get_from_code (l->data);
-		group = add_item_to_menu (totem, menu, lang, current,
+		group = add_item_to_menu (totem, menu, l->data, current,
 				i, is_lang, group);
 		i++;
-		g_free (lang);
 	}
 
 	gtk_widget_show (menu);
@@ -3198,6 +3193,8 @@ video_widget_create (Totem *totem)
 	GError *err = NULL;
 	GtkWidget *container;
 
+	totem->scr = scrsaver_new ();
+
 	totem->bvw = BACON_VIDEO_WIDGET
 		(bacon_video_widget_new (-1, -1, FALSE, &err));
 
@@ -3398,7 +3395,7 @@ process_command_line (BaconMessageConnection *conn, int argc, char **argv)
 
 	if (strlen (argv[1]) > 3 && strncmp (argv[1], "--", 2) != 0)
 	{
-		command = TOTEM_REMOTE_COMMAND_ENQUEUE;
+		command = TOTEM_REMOTE_COMMAND_REPLACE;
 		i = 1;
 	} else if (strcmp (argv[1], "--play-pause") == 0) {
 		command = TOTEM_REMOTE_COMMAND_PAUSE;
@@ -3459,13 +3456,8 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	/* Please also translate your language into its native language
-	 * in src/languages.h
-	 * for example: French -> Francais
-	 * use C UTF-8 strings */
 	g_set_application_name (_("Totem Movie Player"));
 
-	/* FIXME See http://bugzilla.gnome.org/show_bug.cgi?id=111349 */
 	if (XInitThreads () == 0)
 	{
 		gtk_init (&argc, &argv);
@@ -3576,18 +3568,22 @@ main (int argc, char **argv)
 	totem->seekadj = gtk_range_get_adjustment (GTK_RANGE (totem->seek));
 	totem->volume = glade_xml_get_widget (totem->xml, "tmw_volume_hscale");
 	totem->voladj = gtk_range_get_adjustment (GTK_RANGE (totem->volume));
-	totem->exit_popup = glade_xml_get_widget (totem->xml, "totem_exit_fullscreen_window");
-	totem->control_popup = glade_xml_get_widget (totem->xml, "totem_controls_window");
+	totem->exit_popup = glade_xml_get_widget
+		(totem->xml, "totem_exit_fullscreen_window");
+	totem->control_popup = glade_xml_get_widget
+		(totem->xml, "totem_controls_window");
 	totem->fs_seek = glade_xml_get_widget (totem->xml, "tcw_seek_hscale");
 	totem->fs_seekadj = gtk_range_get_adjustment
 		(GTK_RANGE (totem->fs_seek));
-	totem->fs_volume = glade_xml_get_widget (totem->xml, "tcw_volume_hscale");
+	totem->fs_volume = glade_xml_get_widget
+		(totem->xml, "tcw_volume_hscale");
 	totem->fs_voladj = gtk_range_get_adjustment
 		(GTK_RANGE (totem->fs_volume));
 	totem->volume_first_time = 1;
-	totem->fs_pp_button = glade_xml_get_widget (totem->xml, "tcw_pp_button");
+	totem->fs_pp_button = glade_xml_get_widget
+		(totem->xml, "tcw_pp_button");
 	totem->statusbar = glade_xml_get_widget (totem->xml, "tmw_statusbar");
-	
+
 	/* Properties */
 	totem->properties = bacon_video_widget_properties_new ();
 
@@ -3606,8 +3602,6 @@ main (int argc, char **argv)
 	video_widget_create (totem);
 	long_action ();
 
-	totem->scr = scrsaver_new (GDK_DISPLAY ());
-
 	/* The prefs after the video widget is connected */
 	totem_setup_preferences (totem);
 
@@ -3638,3 +3632,4 @@ main (int argc, char **argv)
 
 	return 0;
 }
+
